@@ -51,16 +51,11 @@ package com.openexchange.url.mail.attachment;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.net.InetAddress;
 import java.net.MalformedURLException;
+import java.net.SocketTimeoutException;
 import java.net.URL;
 import java.net.URLConnection;
-import java.net.UnknownHostException;
-import java.util.Set;
-
 import javax.net.ssl.HttpsURLConnection;
-
-import com.google.common.collect.ImmutableSet;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataArguments;
 import com.openexchange.conversion.DataExceptionCodes;
@@ -68,15 +63,12 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.conversion.DataSource;
 import com.openexchange.conversion.SimpleData;
 import com.openexchange.exception.OXException;
-import com.openexchange.java.InetAddresses;
 import com.openexchange.java.Streams;
-import com.openexchange.java.Strings;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MimeType2ExtMap;
 import com.openexchange.session.Session;
-import com.openexchange.tools.net.URITools;
 import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
 
 /**
@@ -91,25 +83,6 @@ public final class URLMailAttachmentDataSource implements DataSource {
      */
     private static final int DEFAULT_TIMEOUT = 10000;
 
-    private static final String LOCAL_HOST_NAME;
-    private static final String LOCAL_HOST_ADDRESS;
-
-    static {
-        // Host name initialization
-        String localHostName;
-        String localHostAddress;
-        try {
-            InetAddress localHost = InetAddress.getLocalHost();
-            localHostName = localHost.getCanonicalHostName();
-            localHostAddress = localHost.getHostAddress();
-        } catch (UnknownHostException e) {
-            localHostName = "localhost";
-            localHostAddress = "127.0.0.1";
-        }
-        LOCAL_HOST_NAME = localHostName;
-        LOCAL_HOST_ADDRESS = localHostAddress;
-    }
-
     /**
      * Initializes a new {@link URLMailAttachmentDataSource}.
      */
@@ -124,9 +97,16 @@ public final class URLMailAttachmentDataSource implements DataSource {
         }
         URLConnection urlCon = null;
         try {
-            /*
-             * Determine read/connect timeout
-             */
+            final URL url;
+            try {
+                final String sUrl = dataArguments.get("url");
+                if (null == sUrl) {
+                    throw DataExceptionCodes.MISSING_ARGUMENT.create("url");
+                }
+                url = new URL(sUrl.trim());
+            } catch (final MalformedURLException e) {
+                throw DataExceptionCodes.ERROR.create(e, e.getMessage());
+            }
             final int timeoutMillis;
             {
                 final String sTimeoutMillis = dataArguments.get("timeout");
@@ -135,36 +115,26 @@ public final class URLMailAttachmentDataSource implements DataSource {
                 } else {
                     try {
                         timeoutMillis = Integer.parseInt(sTimeoutMillis.trim());
-                    } catch (NumberFormatException e) {
+                    } catch (final NumberFormatException e) {
                         throw DataExceptionCodes.INVALID_ARGUMENT.create("timeout", sTimeoutMillis.trim());
                     }
                 }
             }
             /*
-             * Get URL
+             * Open URL connection from parsed URL
              */
+            urlCon = url.openConnection();
+            if ("https".equalsIgnoreCase(url.getProtocol())) {
+                ((HttpsURLConnection) urlCon).setSSLSocketFactory(TrustAllSSLSocketFactory.getDefault());
+            }
+            urlCon.setConnectTimeout(timeoutMillis);
+            urlCon.setReadTimeout(timeoutMillis);
             try {
-                String sUrl = dataArguments.get("url");
-                if (null == sUrl) {
-                    throw DataExceptionCodes.MISSING_ARGUMENT.create("url");
-                }
-                URITools.URLConnectionDecorator decorator = new URITools.URLConnectionDecorator() {
-
-                    @Override
-                    public void decorate(URLConnection con) throws OXException {
-                        try {
-                            if ("https".equalsIgnoreCase(con.getURL().getProtocol())) {
-                                ((HttpsURLConnection) con).setSSLSocketFactory(TrustAllSSLSocketFactory.getDefault());
-                            }
-                            con.setConnectTimeout(timeoutMillis);
-                            con.setReadTimeout(timeoutMillis);
-                        } catch (Exception e) {
-                            throw DataExceptionCodes.ERROR.create(e, e.getMessage());
-                        }
-                    }
-                };
-                urlCon = URITools.getTerminalConnection(sUrl.trim(), VALIDATOR, decorator);
-            } catch (MalformedURLException e) {
+                urlCon.connect();
+            } catch (final SocketTimeoutException e) {
+                /*
+                 * Time-out elapsed
+                 */
                 throw DataExceptionCodes.ERROR.create(e, e.getMessage());
             }
             /*
@@ -236,15 +206,15 @@ public final class URLMailAttachmentDataSource implements DataSource {
              * Return data
              */
             return new SimpleData<D>((D) urlCon.getInputStream(), properties);
-        } catch (OXException e) {
+        } catch (final OXException e) {
             /*
              * No closure of URL connection here
              */
             throw e;
-        } catch (IOException e) {
+        } catch (final IOException e) {
             closeURLConnection(urlCon);
             throw DataExceptionCodes.IO_ERROR.create(e, e.getMessage());
-        } catch (Exception e) {
+        } catch (final Exception e) {
             closeURLConnection(urlCon);
             throw DataExceptionCodes.ERROR.create(e, e.getMessage());
         }
@@ -260,43 +230,6 @@ public final class URLMailAttachmentDataSource implements DataSource {
         }
     }
 
-    private static final Set<String> ALLOWED_PROTOCOLS = ImmutableSet.of("http", "https", "ftp", "ftps");
-    private static final Set<String> DENIED_HOSTS = ImmutableSet.of("localhost", "127.0.0.1", LOCAL_HOST_ADDRESS, LOCAL_HOST_NAME);
-
-    /**
-     * Validates the given URL according to white-listed protocols and blacklisted hosts.
-     *
-     * @param url The URL to validate
-     * @return An optional OXException
-     */
-    private static URITools.UrlValidator VALIDATOR = new URITools.UrlValidator() {
-        
-        final Set<String> ALLOWED_PROTOCOLS = ImmutableSet.of("http", "https", "ftp", "ftps");
-        final Set<String> DENIED_HOSTS = ImmutableSet.of("localhost", "127.0.0.1", LOCAL_HOST_ADDRESS, LOCAL_HOST_NAME);
-
-        @Override
-        public void validate(URL url) throws OXException {
-            String protocol = url.getProtocol();
-            if (protocol == null || !ALLOWED_PROTOCOLS.contains(Strings.asciiLowerCase(protocol))) {
-                throw DataExceptionCodes.INVALID_ARGUMENT.create("url", url.toString());
-            }
-
-            String host = Strings.asciiLowerCase(url.getHost());
-            if (host == null || DENIED_HOSTS.contains(host)) {
-                throw DataExceptionCodes.INVALID_ARGUMENT.create("url", url.toString());
-            }
-
-            try {
-                InetAddress inetAddress = InetAddress.getByName(url.getHost());
-                if (InetAddresses.isInternalAddress(inetAddress)) {
-                    throw DataExceptionCodes.INVALID_ARGUMENT.create("url", url.toString());
-                }
-            } catch (UnknownHostException e) {
-                throw DataExceptionCodes.INVALID_ARGUMENT.create("url", url.toString());
-            }
-        }
-    };
-
     @Override
     public String[] getRequiredArguments() {
         return new String[] { "url" };
